Node

Struct Node 

pub struct Node<E: NodeEntry = ChunkAddress> { /* private fields */ }
A node in the mantaray trie.

Implementations

Source

impl<E: NodeEntry> Node<E>

pub fn new_unencrypted() -> Self

Create a new node with a zeroed obfuscation key (unencrypted).

pub fn from_reference(reference: ChunkAddress) -> Self

Create a node that references persisted data.

pub const fn entry(&self) -> Option<&E>

The typed entry stored at this node.

pub const fn metadata(&self) -> &BTreeMap<String, String>

Metadata key-value pairs attached to this node.

pub const fn reference(&self) -> Option<&ChunkAddress>

Content-addressed reference for this node.

pub const fn forks(&self) -> &BTreeMap<u8, Fork<E>>

Child forks keyed by the first byte of their prefix.

pub const fn obfuscation_key(&self) -> &ObfuscationKey

XOR obfuscation key for binary serialisation.

pub const fn is_value(&self) -> bool

Check if the node has a value (entry).

pub const fn is_edge(&self) -> bool

Check if the node has child forks.

pub const fn is_with_path_separator(&self) -> bool

Check if the path contains a separator.

pub const fn is_with_metadata(&self) -> bool

Check if the node has metadata.