pub struct Node<E: NodeEntry = ChunkAddress> { /* private fields */ }Expand description
A node in the mantaray trie.
Implementations
Sourceimpl<E: NodeEntry> Node<E>
impl<E: NodeEntry> Node<E>
Sourcepub fn new_unencrypted() -> Self
pub fn new_unencrypted() -> Self
Create a new node with a zeroed obfuscation key (unencrypted).
Sourcepub fn from_reference(reference: ChunkAddress) -> Self
pub fn from_reference(reference: ChunkAddress) -> Self
Create a node that references persisted data.
Sourcepub const fn metadata(&self) -> &BTreeMap<String, String>
pub const fn metadata(&self) -> &BTreeMap<String, String>
Metadata key-value pairs attached to this node.
Sourcepub const fn reference(&self) -> Option<&ChunkAddress>
pub const fn reference(&self) -> Option<&ChunkAddress>
Content-addressed reference for this node.
Sourcepub const fn forks(&self) -> &BTreeMap<u8, Fork<E>>
pub const fn forks(&self) -> &BTreeMap<u8, Fork<E>>
Child forks keyed by the first byte of their prefix.
Sourcepub const fn obfuscation_key(&self) -> &ObfuscationKey
pub const fn obfuscation_key(&self) -> &ObfuscationKey
XOR obfuscation key for binary serialisation.
Sourcepub const fn is_with_path_separator(&self) -> bool
pub const fn is_with_path_separator(&self) -> bool
Check if the path contains a separator.
Sourcepub const fn is_with_metadata(&self) -> bool
pub const fn is_with_metadata(&self) -> bool
Check if the node has metadata.